@@ -12,7 +12,7 @@
 
 // #include the widget headers so that we can call the get_type() static methods:
 
-#include "gtkmozembedmm/gtkmozembedmm.h"
+#include "webcontrol.h"
 
 extern "C"
 {
